@@ -7,10 +7,12 @@ import java.nio.channels.*;
 
 import javax.net.ssl.*;
 
+import nl.dannyvanheumen.nio.*;
+
 public class SocketChannelConnection implements IConnection
 {
 	private SocketChannel channel;
-	private ByteBuffer buffer = ByteBuffer.allocate(2048);
+	private final ByteBuffer buffer = ByteBuffer.allocate(2048);
 
 	@Override
 	public int write(String aMessage) throws IOException
@@ -19,11 +21,30 @@ public class SocketChannelConnection implements IConnection
 	}
 
 	@Override
-	public boolean open(String aHostname, int aPort, SSLContext aCtx) throws IOException
+	public boolean open(String aHostname, int aPort, SSLContext aCtx, Proxy aProxy, boolean resolveThroughProxy) throws IOException
 	{
 		if (channel == null || !channel.isConnected())
 		{
-			return (channel = SocketChannel.open()).connect(new InetSocketAddress(aHostname, aPort));
+			final InetSocketAddress address;
+			if (aProxy != null && aProxy.type() == Proxy.Type.SOCKS)
+			{
+				channel = new ProxiedSocketChannel(aProxy);
+				if (resolveThroughProxy)
+				{
+					address = InetSocketAddress.createUnresolved(aHostname, aPort);
+				}
+				else
+				{
+					address = new InetSocketAddress(aHostname, aPort);
+				}
+			}
+			else
+			{
+				// Configured to not use a proxy, using the original SocketChannel.
+				channel = SocketChannel.open();
+				address = new InetSocketAddress(aHostname, aPort);
+			}
+			return channel.connect(address);
 		}
 		else
 		{
