@@ -1,11 +1,13 @@
 package com.ircclouds.irc.api.domain;
 
+import java.net.*;
+
 import javax.net.ssl.*;
 
 public class SecureIRCServer extends IRCServer
 {
 	private SSLContext sslContext;
-	
+
 	public SecureIRCServer(String aHostname)
 	{
 		super(aHostname, true);
@@ -18,32 +20,46 @@ public class SecureIRCServer extends IRCServer
 
 	public SecureIRCServer(String aHostname, int aPort, String aPassword)
 	{
-		super(aHostname, aPort, aPassword, true);		
+		super(aHostname, aPort, aPassword, true);
 	}
-	
+
 	public SecureIRCServer(String aHostname, SSLContext aSSLContext)
 	{
 		super(aHostname, true);
-		
+
 		sslContext = aSSLContext;
 	}
-	
+
 	public SecureIRCServer(String aHostname, int aPort, SSLContext aSSLContext)
 	{
 		super(aHostname, aPort, "", true);
-		
-		sslContext = aSSLContext;
-	}	
 	
+		sslContext = aSSLContext;
+	}
+
+	public SecureIRCServer(String aHostname, int aPort, SSLContext aSSLContext, Proxy aProxy, boolean aResolveByProxy)
+	{
+		super(aHostname, aPort, "", true, aProxy, aResolveByProxy);
+
+		sslContext = aSSLContext;
+	}
+
 	public SecureIRCServer(String aHostname, int aPort, String aPassword, SSLContext aSSLContext)
 	{
 		super(aHostname, aPort, aPassword, true);
-		
+
 		sslContext = aSSLContext;
-	}	
-	
+	}
+
+	public SecureIRCServer(String aHostname, int aPort, String aPassword, SSLContext aSSLContext, Proxy aProxy, boolean aResolveByProxy)
+	{
+		super(aHostname, aPort, aPassword, true, aProxy, aResolveByProxy);
+
+		sslContext = aSSLContext;
+	}
+
 	public SSLContext getSSLContext()
 	{
-			return sslContext;		
+		return sslContext;
 	}
 }
