@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.gui.main;
 
@@ -339,7 +350,13 @@ public class MainFrame
 
         searchPanel.add(searchField);
         searchPanel.add(new DialPadButton(), BorderLayout.WEST);
-        searchPanel.add(createButtonPanel(), BorderLayout.EAST);
+
+        if(!GuiActivator.getConfigurationService().getBoolean(
+            "net.java.sip.communicator.impl.gui.CALL_HISTORY_BUTTON_DISABLED",
+            false))
+        {
+            searchPanel.add(createButtonPanel(), BorderLayout.EAST);
+        }
 
         northPanel.add(accountStatusPanel, BorderLayout.CENTER);
         northPanel.add(searchPanel, BorderLayout.SOUTH);
@@ -382,7 +399,7 @@ public class MainFrame
         boolean isCallButtonEnabled = false;
 
         // Indicates if the big call button outside the search is enabled.
-        String callButtonEnabledString = UtilActivator.getResources()
+        String callButtonEnabledString = GuiActivator.getResources()
             .getSettingsString("impl.gui.CALL_BUTTON_ENABLED");
 
         if (callButtonEnabledString != null
@@ -1903,7 +1920,8 @@ public class MainFrame
         // On Mac systems the application is not quited on window close, so we
         // don't need to warn the user.
         if (!GuiActivator.getUIService().getExitOnMainWindowClose()
-            && !OSUtils.IS_MAC)
+            && !OSUtils.IS_MAC
+            && GuiActivator.getSystrayService().checkInitialized())
         {
             SwingUtilities.invokeLater(new Runnable()
             {
@@ -1925,6 +1943,10 @@ public class MainFrame
             });
 
             ConfigurationUtils.setApplicationVisible(false);
+            if (ConfigurationUtils.isMinimizeInsteadOfHide())
+            {
+                this.minimize();
+            }
         }
     }
 
