@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.gui.main.chat;
 
@@ -213,10 +224,11 @@ public class ChatContactRightButtonMenu
                 ? room.getUserRole()
                 : ((ChatRoomMember) chatContact.getDescriptor()).getRole();
         int roleIndex = role.getRoleIndex();
-        String roleName = role.getRoleName();
+        String roleName = role.getLocalizedRoleName();
 
-        JLabel jl_username
-            = new JLabel(" "+chatContact.getName()+" ("+roleName+") ");
+        JLabel jl_username =
+            new JLabel(" " + chatContact.getName() + " ("
+                + GuiActivator.getResources().getI18NString(roleName) + ") ");
         jl_username.setFont(jl_username.getFont().deriveFont(Font.BOLD));
 
         this.add(jl_username);
