@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.gui.main.contactlist;
 
@@ -556,6 +567,12 @@ public class ContactListPane
             errorMsg = GuiActivator.getResources().getI18NString(
                     "service.gui.MSG_DELIVERY_INTERNAL_ERROR");
         }
+        else if (evt.getErrorCode()
+                == MessageDeliveryFailedEvent.UNSUPPORTED_OPERATION)
+        {
+            errorMsg = GuiActivator.getResources().getI18NString(
+                "service.gui.MSG_DELIVERY_UNSUPPORTED_OPERATION");
+        }
         else
         {
             errorMsg = GuiActivator.getResources().getI18NString(
