@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.history;
 
@@ -172,9 +183,11 @@ public class HistoryServiceImpl
         {
             if (this.histories.containsKey(id))
             {
-                throw new IllegalArgumentException(
-                        "There is already a history with the specified ID.");
-            } else {
+                retVal = this.histories.get(id);
+                retVal.setHistoryRecordsStructure(recordStructure);
+            }
+            else
+            {
                 File dir = this.createHistoryDirectories(id);
                 HistoryImpl history = new HistoryImpl(id, dir, recordStructure,
                         this);
@@ -212,7 +225,10 @@ public class HistoryServiceImpl
     protected synchronized Document parse(File file)
         throws SAXException, IOException
     {
-        return builder.parse(file);
+        FileInputStream fis = new FileInputStream(file);
+        Document doc = builder.parse(fis);
+        fis.close();
+        return doc;
     }
 
     /**
