@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.protocol.jabber;
 
@@ -299,7 +310,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
      * activity (i.e. neither outgoing nor incoming messags) for more than
      * JID_INACTIVITY_TIMEOUT. Note that this method is not synchronous and that
      * it is only meant for use by the {@link #getThreadIDForAddress(String)} and
-     * {@link #putJidForAddress(String, String, Chat)}
+     * {@link #putJidForAddress(String, String)}
      */
     private void purgeOldJids()
     {
@@ -327,7 +338,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
      * entries that haven't seen any activity (i.e. no one has tried to get or
      * remap it) for a delay longer than <tt>JID_INACTIVITY_TIMEOUT</tt>.
      *
-     * @param address the <tt>address</tt> that we'd like to obtain a jid for.
+     * @param jid the <tt>jid</tt> that we'd like to obtain a threadID for.
      *
      * @return the last jid that the party with the specified <tt>address</tt>
      * contacted us from or <tt>null</tt> if we don't have a jid for the
@@ -355,8 +366,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
      * the specified <tt>address</tt> to the <tt>jid</tt> that they last
      * contacted us from.
      *
-     * @param address the bare address (i.e. no resource included) of the
-     * contact that we'd like to set a jid for.
+     * @param threadID the threadID of conversation.
      * @param jid the jid (i.e. address/resource) that the contact with the
      * specified <tt>address</tt> last contacted us from.
      */
@@ -473,7 +483,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
 
             // msg.addExtension(new Version());
 
-            if (event.isMessageEncrypted())
+            if (event.isMessageEncrypted() && isCarbonEnabled)
             {
                 msg.addExtension(new CarbonPacketExtension.PrivateExtension());
             }
@@ -494,10 +504,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
             putJidForAddress(toJID, threadID);
         }
 
-        MessageDeliveredEvent msgDeliveredEvt =
-            new MessageDeliveredEvent(message, to, toResource);
-
-        return msgDeliveredEvt;
+        return new MessageDeliveredEvent(message, to, toResource);
     }
 
     /**
@@ -630,31 +637,14 @@ public class OperationSetBasicInstantMessagingJabberImpl
             }
             else if (evt.getNewState() == RegistrationState.REGISTERED)
             {
-                //subscribe for Google (Gmail or Google Apps) notifications
-                //for new mail messages.
-                boolean enableGmailNotifications
-                   = jabberProvider
-                       .getAccountID()
-                           .getAccountPropertyBoolean(
-                               "GMAIL_NOTIFICATIONS_ENABLED",
-                               false);
-
-                if (enableGmailNotifications)
-                    subscribeForGmailNotifications();
-
-                boolean enableCarbon
-                    = isCarbonSupported() && !jabberProvider.getAccountID()
-                            .getAccountPropertyBoolean(
-                                ProtocolProviderFactory.IS_CARBON_DISABLED,
-                                false);
-                if(enableCarbon)
+                new Thread(new Runnable()
                 {
-                    enableDisableCarbon(true);
-                }
-                else
-                {
-                    isCarbonEnabled = false;
-                }
+                    @Override
+                    public void run()
+                    {
+                        initAdditionalServices();
+                    }
+                }).start();
             }
             else if(evt.getNewState() == RegistrationState.UNREGISTERED
                 || evt.getNewState() == RegistrationState.CONNECTION_FAILED
@@ -670,9 +660,40 @@ public class OperationSetBasicInstantMessagingJabberImpl
                 smackMessageListener = null;
             }
         }
-
     }
 
+    /**
+     * Initialize additional services, like gmail notifications and message
+     * carbons.
+     */
+    private void initAdditionalServices()
+    {
+        //subscribe for Google (Gmail or Google Apps) notifications
+        //for new mail messages.
+        boolean enableGmailNotifications
+            = jabberProvider
+            .getAccountID()
+            .getAccountPropertyBoolean(
+                "GMAIL_NOTIFICATIONS_ENABLED",
+                false);
+
+        if (enableGmailNotifications)
+            subscribeForGmailNotifications();
+
+        boolean enableCarbon
+            = isCarbonSupported() && !jabberProvider.getAccountID()
+            .getAccountPropertyBoolean(
+                ProtocolProviderFactory.IS_CARBON_DISABLED,
+                false);
+        if(enableCarbon)
+        {
+            enableDisableCarbon(true);
+        }
+        else
+        {
+            isCarbonEnabled = false;
+        }
+    }
 
     /**
      * Sends enable or disable carbon packet to the server.
@@ -734,7 +755,6 @@ public class OperationSetBasicInstantMessagingJabberImpl
         {
             isCarbonEnabled = true;
         }
-
     }
 
     /**
@@ -752,7 +772,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
         }
         catch (XMPPException e)
         {
-           logger.error("Failed to retrieve carbon support.",e);
+           logger.warn("Failed to retrieve carbon support." + e.getMessage());
         }
         return false;
     }
@@ -815,9 +835,13 @@ public class OperationSetBasicInstantMessagingJabberImpl
             String userBareID = StringUtils.parseBareAddress(userFullId);
 
             boolean isPrivateMessaging = false;
-            ChatRoom privateContactRoom = ((OperationSetMultiUserChatJabberImpl)
-                jabberProvider.getOperationSet(OperationSetMultiUserChat.class))
-                    .getChatRoom(userBareID);
+            ChatRoom privateContactRoom = null;
+            OperationSetMultiUserChatJabberImpl mucOpSet =
+                (OperationSetMultiUserChatJabberImpl)jabberProvider
+                    .getOperationSet(OperationSetMultiUserChat.class);
+            if(mucOpSet != null)
+                privateContactRoom = mucOpSet.getChatRoom(userBareID);
+
             if(privateContactRoom != null)
             {
                 isPrivateMessaging = true;
@@ -929,22 +953,31 @@ public class OperationSetBasicInstantMessagingJabberImpl
                 if (logger.isInfoEnabled())
                     logger.info("Message error received from " + userBareID);
 
-                int errorCode = packet.getError().getCode();
                 int errorResultCode = MessageDeliveryFailedEvent.UNKNOWN_ERROR;
-
-                if(errorCode == 503)
+                if (packet.getError() != null)
                 {
-                    org.jivesoftware.smackx.packet.MessageEvent msgEvent =
-                        (org.jivesoftware.smackx.packet.MessageEvent)
-                            packet.getExtension("x", "jabber:x:event");
-                    if(msgEvent != null && msgEvent.isOffline())
+                    int errorCode = packet.getError().getCode();
+    
+                    if(errorCode == 503)
                     {
-                        errorResultCode =
-                            MessageDeliveryFailedEvent
-                                .OFFLINE_MESSAGES_NOT_SUPPORTED;
+                        org.jivesoftware.smackx.packet.MessageEvent msgEvent =
+                            (org.jivesoftware.smackx.packet.MessageEvent)
+                                packet.getExtension("x", "jabber:x:event");
+                        if(msgEvent != null && msgEvent.isOffline())
+                        {
+                            errorResultCode =
+                                MessageDeliveryFailedEvent
+                                    .OFFLINE_MESSAGES_NOT_SUPPORTED;
+                        }
                     }
                 }
 
+                if (sourceContact == null)
+                {
+                    sourceContact = opSetPersPresence.createVolatileContact(
+                        userFullId, isPrivateMessaging);
+                }
+
                 MessageDeliveryFailedEvent ev
                     = new MessageDeliveryFailedEvent(newMessage,
                                                      sourceContact,
@@ -1128,7 +1161,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
                     Integer.toString( threadCount )//{2} - thread count
                 });
 
-        StringBuffer message = new StringBuffer(newMailHeader);
+        StringBuilder message = new StringBuilder(newMailHeader);
 
         //we now start an html table for the threads.
         message.append("<table width=100% cellpadding=2 cellspacing=0 ");
@@ -1195,7 +1228,7 @@ public class OperationSetBasicInstantMessagingJabberImpl
          */
         public void processPacket(Packet packet)
         {
-            if(packet != null &&  !(packet instanceof MailboxIQ))
+            if(packet != null && !(packet instanceof MailboxIQ))
                 return;
 
             MailboxIQ mailboxIQ = (MailboxIQ) packet;
