@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.protocol.jabber;
 
@@ -12,6 +23,7 @@ import net.java.sip.communicator.impl.protocol.jabber.extensions.*;
 import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
 import net.java.sip.communicator.service.protocol.*;
 import net.java.sip.communicator.service.protocol.event.*;
+import net.java.sip.communicator.service.protocol.jabber.*;
 import net.java.sip.communicator.service.protocol.media.*;
 import net.java.sip.communicator.util.*;
 
@@ -344,7 +356,7 @@ public class OperationSetBasicTelephonyJabberImpl
         }
 
         String bypassDomain = accountID.getAccountPropertyString(
-            "TELEPHONY_BYPASS_GTALK_CAPS");
+                JabberAccountID.TELEPHONY_BYPASS_GTALK_CAPS);
 
         boolean alwaysCallGtalk
             = ((bypassDomain != null)
@@ -353,9 +365,12 @@ public class OperationSetBasicTelephonyJabberImpl
                                     calleeAddress.indexOf('@') + 1)))
                 || isGoogleVoice;
 
-        boolean isPrivateMessagingContact = getProtocolProvider()
-            .getOperationSet(OperationSetMultiUserChat.class)
-            .isPrivateMessagingContact(calleeAddress);
+        boolean isPrivateMessagingContact = false;
+        OperationSetMultiUserChat mucOpSet = getProtocolProvider()
+            .getOperationSet(OperationSetMultiUserChat.class);
+        if(mucOpSet != null)
+            isPrivateMessagingContact
+                = mucOpSet.isPrivateMessagingContact(calleeAddress);
 
         if((!getProtocolProvider().getConnection().getRoster().contains(
             StringUtils.parseBareAddress(calleeAddress)) &&
@@ -370,13 +385,13 @@ public class OperationSetBasicTelephonyJabberImpl
         // connected one with highest priority.
         if (fullCalleeURI == null)
             fullCalleeURI = 
-                discoverFullJid(calleeAddress, alwaysCallGtalk);
+                discoverFullJid(calleeAddress);
 
         if (fullCalleeURI == null)
             throw new OperationFailedException(
                     "Failed to create outgoing call to " + calleeAddress
                             + ". Could not find a resource which supports " +
-                            "Jingle or Google Talk",
+                            "Jingle",
                     OperationFailedException.INTERNAL_ERROR);
 
         DiscoverInfo di = null;
@@ -404,7 +419,7 @@ public class OperationSetBasicTelephonyJabberImpl
 
             throw new OperationFailedException(
                     "Failed to create an outgoing call.\n"
-                    + fullCalleeURI + " does not support jingle or Google Talk",
+                    + fullCalleeURI + " does not support jingle",
                     OperationFailedException.INTERNAL_ERROR);
         }
 
@@ -462,18 +477,14 @@ public class OperationSetBasicTelephonyJabberImpl
      * priority which supports either Jingle or Gtalk. Returns the full JID.
      *
      * @param calleeAddress the address of the callee
-     * @param isAlwaysCallGtalk indicates if gtalk should be called
      *
      * @return the full callee URI
      */
-    private String discoverFullJid( String calleeAddress,
-                                    boolean isAlwaysCallGtalk)
+    private String discoverFullJid(String calleeAddress)
     {
         String fullCalleeURI = null;
         DiscoverInfo discoverInfo = null;
         int bestPriority = -1;
-        boolean isGingle = false;
-        String gingleURI = null;
         PresenceStatus jabberStatus = null;
         String calleeURI = null;
 
@@ -502,11 +513,6 @@ public class OperationSetBasicTelephonyJabberImpl
                 logger.warn("could not retrieve info for " + fullCalleeURI, ex);
             }
 
-            boolean hasGtalkCaps =
-                getProtocolProvider().isExtFeatureListSupported(
-                    calleeURI, ProtocolProviderServiceJabberImpl.
-                        CAPS_GTALK_WEB_VOICE);
-
             if (discoverInfo != null && discoverInfo.containsFeature(
                 ProtocolProviderServiceJabberImpl.URN_XMPP_JINGLE))
             {
@@ -514,7 +520,6 @@ public class OperationSetBasicTelephonyJabberImpl
                 {
                     bestPriority = priority;
                     fullCalleeURI = calleeURI;
-                    isGingle = false;
                     jabberStatus = OperationSetPersistentPresenceJabberImpl
                         .jabberStatusToPresenceStatus(
                                 presence, protocolProvider);
@@ -528,45 +533,12 @@ public class OperationSetBasicTelephonyJabberImpl
                     if(tempStatus.compareTo(jabberStatus) > 0)
                     {
                         fullCalleeURI = calleeURI;
-                        isGingle = false;
                         jabberStatus = tempStatus;
                     }
                 }
             }
-            else if (protocolProvider.isGTalkTesting() // GTalk enabled locally
-                    // see if peer supports Google Talk voice
-                    && (hasGtalkCaps || isAlwaysCallGtalk))
-            {
-                if(priority > bestPriority)
-                {
-                    bestPriority = priority;
-                    isGingle = true;
-                    gingleURI = calleeURI;
-                    jabberStatus =OperationSetPersistentPresenceJabberImpl
-                        .jabberStatusToPresenceStatus(  presence,
-                                                        protocolProvider);
-                }
-                else if(priority == bestPriority && jabberStatus != null)
-                {
-                    PresenceStatus tempStatus =
-                        OperationSetPersistentPresenceJabberImpl
-                           .jabberStatusToPresenceStatus(
-                               presence, protocolProvider);
-                    if(tempStatus.compareTo(jabberStatus) > 0)
-                    {
-                        isGingle = true;
-                        gingleURI = calleeURI;
-                        jabberStatus =OperationSetPersistentPresenceJabberImpl
-                            .jabberStatusToPresenceStatus(
-                                presence, protocolProvider);
-                    }
-                }
-            }
         }
 
-        if(isGingle)
-            fullCalleeURI = gingleURI;
-
         if(logger.isInfoEnabled())
             logger.info("Full JID for outgoing call: " + fullCalleeURI
                             + ", priority " + bestPriority);
