@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.protocol.jabber;
 
@@ -112,8 +123,22 @@ public class OperationSetPersistentPresenceJabberImpl
     private VCardTempXUpdatePresenceExtension vCardTempXUpdatePresenceExtension
         = null;
 
+    /**
+     * Handles all the logic about mobile indicator for contacts.
+     */
     private final MobileIndicator mobileIndicator;
 
+    /**
+     * The last sent presence to server, contains the status, the resource
+     * and its priority.
+     */
+    private Presence currentPresence = null;
+
+    /**
+     * The local contact presented by the provider.
+     */
+    private ContactJabberImpl localContact = null;
+
     /**
      * Creates the OperationSet.
      * @param provider the parent provider.
@@ -366,7 +391,93 @@ public class OperationSetPersistentPresenceJabberImpl
      */
     public Contact getLocalContact()
     {
-        return null;
+        if(localContact != null)
+            return localContact;
+
+        final String id = parentProvider.getAccountID().getUserID();
+
+        localContact
+            = new ContactJabberImpl(null, ssContactList, false, true);
+        localContact.setLocal(true);
+        localContact.updatePresenceStatus(currentStatus);
+        localContact.setJid(parentProvider.getOurJID());
+
+        Map<String, ContactResourceJabberImpl> rs
+            = localContact.getResourcesMap();
+
+        if(currentPresence != null)
+            rs.put(parentProvider.getOurJID(),
+                createResource( currentPresence,
+                                parentProvider.getOurJID(),
+                                localContact));
+
+        Iterator<Presence> presenceIterator = ssContactList.getPresences(id);
+        while(presenceIterator.hasNext())
+        {
+            Presence p = presenceIterator.next();
+
+            String fullJid = p.getFrom();
+            rs.put(fullJid, createResource(p, p.getFrom(), localContact));
+        }
+
+        // adds xmpp listener for changes in the local contact resources
+        PacketFilter presenceFilter = new PacketTypeFilter(Presence.class);
+        parentProvider.getConnection()
+            .addPacketListener(
+                new PacketListener()
+                {
+                    @Override
+                    public void processPacket(Packet packet)
+                    {
+                        Presence presence = (Presence) packet;
+                        String from = presence.getFrom();
+
+                        if(from == null
+                            || !StringUtils.parseBareAddress(from).equals(id))
+                            return;
+
+                        // own resource update, let's process it
+                        updateResource(localContact, null, presence);
+                    }
+                }, presenceFilter);
+
+        return localContact;
+    }
+
+    /**
+     * Creates ContactResource from the presence, full jid and contact.
+     * @param presence the presence object.
+     * @param fullJid the full jid for the resource.
+     * @param contact the contact.
+     * @return the newly created resource.
+     */
+    private ContactResourceJabberImpl createResource(
+        Presence presence,
+        String fullJid,
+        Contact contact)
+    {
+        String resource = StringUtils.parseResource(fullJid);
+
+        return new ContactResourceJabberImpl(
+            fullJid,
+            contact,
+            resource,
+            jabberStatusToPresenceStatus(presence, parentProvider),
+            presence.getPriority(),
+            mobileIndicator.isMobileResource(resource, fullJid));
+    }
+
+    /**
+     * Clear resources used for local contact and before that update its
+     * resources in order to fire the needed events.
+     */
+    private void clearLocalContactResources()
+    {
+        if(localContact != null)
+            removeResource(localContact, localContact.getAddress());
+
+        currentPresence = null;
+        localContact = null;
     }
 
     /**
@@ -482,13 +593,31 @@ public class OperationSetPersistentPresenceJabberImpl
             throw new IllegalArgumentException(status
                 + " is not a valid Jabber status");
 
+        // if we got publish presence and we are still in a process of
+        // initializing the roster, just save the status and we will dispatch
+        // it when we are ready with the roster as sending initial presence
+        // is recommended to be done after requesting the roster, but we want
+        // to also dispatch it
+        synchronized(ssContactList.getRosterInitLock())
+        {
+            if(!ssContactList.isRosterInitialized())
+            {
+                // store it
+                ssContactList.setInitialStatus(status);
+                ssContactList.setInitialStatusMessage(statusMessage);
+                return;
+            }
+        }
+
         if (status.equals(jabberStatusEnum.getStatus(JabberStatusEnum.OFFLINE)))
         {
             parentProvider.unregister();
+            clearLocalContactResources();
         }
         else
         {
             Presence presence = new Presence(Presence.Type.available);
+            currentPresence = presence;
             presence.setMode(presenceStatusToJabberMode(status));
             presence.setPriority(
                 getPriorityForPresenceStatus(status.getStatusName()));
@@ -510,6 +639,10 @@ public class OperationSetPersistentPresenceJabberImpl
             //presence.addExtension(new Version());
 
             parentProvider.getConnection().sendPacket(presence);
+
+            if(localContact != null)
+                updateResource(localContact,
+                    parentProvider.getOurJID(), presence);
         }
 
         fireProviderStatusChangeEvent(currentStatus, status);
@@ -944,12 +1077,16 @@ public class OperationSetPersistentPresenceJabberImpl
                 // note that our listener will be added just before the
                 // one used in the Roster itself, but later we
                 // will wait for it to be ready
-                // (inside method XMPPConnection.getRoaster())
+                // (inside method XMPPConnection.getRoster())
                 parentProvider.getConnection().addPacketListener(
                     new ServerStoredListInit(),
                     new PacketTypeFilter(RosterPacket.class)
                 );
 
+                // will be used to store presence events till roster is
+                // initialized
+                contactChangesListener = new ContactChangesListener();
+
                 // Adds subscription listener as soon as connection is created
                 // or we can miss some subscription requests
                 if(subscribtionPacketListener == null)
@@ -981,20 +1118,23 @@ public class OperationSetPersistentPresenceJabberImpl
                     parentProvider.getJabberStatusEnum().getStatus(
                         JabberStatusEnum.OFFLINE);
                 currentStatus = offlineStatus;
+                clearLocalContactResources();
 
                 fireProviderStatusChangeEvent(oldStatus, currentStatus);
 
                 ssContactList.cleanup();
-                subscribtionPacketListener = null;
 
                 XMPPConnection connection = parentProvider.getConnection();
                 if(connection != null)
                 {
+                    connection.removePacketListener(subscribtionPacketListener);
+
                     // the roster is guaranteed to be non-null
                     connection.getRoster()
                         .removeRosterListener(contactChangesListener);
                 }
 
+                subscribtionPacketListener = null;
                 contactChangesListener = null;
             }
         }
@@ -1056,70 +1196,7 @@ public class OperationSetPersistentPresenceJabberImpl
         {
             Presence presence = it.next();
 
-            String resource = StringUtils.parseResource(presence.getFrom());
-
-            if (resource != null && resource.length() > 0)
-            {
-                String fullJid = presence.getFrom();
-                ContactResourceJabberImpl contactResource
-                    = resources.get(fullJid);
-
-                PresenceStatus newPresenceStatus
-                    = OperationSetPersistentPresenceJabberImpl
-                        .jabberStatusToPresenceStatus(
-                            presence,
-                            parentProvider);
-
-                if (contactResource == null)
-                {
-                    contactResource = new ContactResourceJabberImpl(
-                        fullJid,
-                        contact,
-                        resource,
-                        newPresenceStatus,
-                        presence.getPriority(),
-                        mobileIndicator.isMobileResource(resource, fullJid));
-
-                    resources.put(fullJid, contactResource);
-
-                    contact.fireContactResourceEvent(
-                        new ContactResourceEvent(contact, contactResource,
-                            ContactResourceEvent.RESOURCE_ADDED));
-                    eventFired = true;
-                }
-                else
-                {
-                    boolean oldIndicator = contactResource.isMobile();
-                    boolean newIndicator =
-                        mobileIndicator.isMobileResource(resource, fullJid);
-                    int oldPriority = contactResource.getPriority();
-
-                    // update mobile indicator, as cabs maybe added after
-                    // creating the resource for the contact
-                    contactResource.setMobile(newIndicator);
-
-                    contactResource.setPriority(presence.getPriority());
-                    if(oldPriority != contactResource.getPriority())
-                    {
-                        // priority has been updated so update and the
-                        // mobile indicator before firing an event
-                        mobileIndicator.resourcesUpdated(contact);
-                    }
-
-                    if (contactResource.getPresenceStatus().getStatus()
-                        != newPresenceStatus.getStatus()
-                        || (oldIndicator != newIndicator)
-                        || (oldPriority != contactResource.getPriority()))
-                    {
-                        contactResource.setPresenceStatus(newPresenceStatus);
-
-                        contact.fireContactResourceEvent(
-                            new ContactResourceEvent(contact, contactResource,
-                                ContactResourceEvent.RESOURCE_MODIFIED));
-                        eventFired = true;
-                    }
-                }
-            }
+            eventFired = updateResource(contact, null, presence) || eventFired;
         }
 
         if(!removeUnavailable)
@@ -1133,23 +1210,116 @@ public class OperationSetPersistentPresenceJabberImpl
             if(!parentProvider.getConnection().getRoster()
                     .getPresenceResource(fullJid).isAvailable())
             {
-                ContactResource removedResource = resources.get(fullJid);
-
-                if (resources.containsKey(fullJid))
-                {
-                    resources.remove(fullJid);
-
-                    contact.fireContactResourceEvent(
-                        new ContactResourceEvent(contact, removedResource,
-                            ContactResourceEvent.RESOURCE_REMOVED));
-                    eventFired = true;
-                }
+                eventFired = removeResource(contact, fullJid) || eventFired;
             }
         }
 
         return eventFired;
     }
 
+    /**
+     * Update the resources for the contact for the received presence.
+     * @param contact the contact which resources to update.
+     * @param fullJid the full jid to use, if null will use those from the
+     * presence packet
+     * @param presence the presence packet to use to get info.
+     * @return whether resource has been updated
+     */
+    private boolean updateResource(ContactJabberImpl contact,
+                                   String fullJid,
+                                   Presence presence)
+    {
+
+        if(fullJid == null)
+            fullJid = presence.getFrom();
+
+        String resource = StringUtils.parseResource(fullJid);
+
+        if (resource != null && resource.length() > 0)
+        {
+            Map<String, ContactResourceJabberImpl> resources =
+                contact.getResourcesMap();
+
+            ContactResourceJabberImpl contactResource
+                = resources.get(fullJid);
+
+            PresenceStatus newPresenceStatus
+                = OperationSetPersistentPresenceJabberImpl
+                    .jabberStatusToPresenceStatus(presence, parentProvider);
+
+            if (contactResource == null)
+            {
+                contactResource = createResource(presence, fullJid, contact);
+
+                resources.put(fullJid, contactResource);
+
+                contact.fireContactResourceEvent(
+                    new ContactResourceEvent(contact, contactResource,
+                        ContactResourceEvent.RESOURCE_ADDED));
+                return true;
+            }
+            else
+            {
+                boolean oldIndicator = contactResource.isMobile();
+                boolean newIndicator =
+                    mobileIndicator.isMobileResource(resource, fullJid);
+                int oldPriority = contactResource.getPriority();
+
+                // update mobile indicator, as cabs maybe added after
+                // creating the resource for the contact
+                contactResource.setMobile(newIndicator);
+
+                contactResource.setPriority(presence.getPriority());
+                if(oldPriority != contactResource.getPriority())
+                {
+                    // priority has been updated so update and the
+                    // mobile indicator before firing an event
+                    mobileIndicator.resourcesUpdated(contact);
+                }
+
+                if (contactResource.getPresenceStatus().getStatus()
+                        != newPresenceStatus.getStatus()
+                    || (oldIndicator != newIndicator)
+                    || (oldPriority != contactResource.getPriority()))
+                {
+                    contactResource.setPresenceStatus(newPresenceStatus);
+
+                    contact.fireContactResourceEvent(
+                        new ContactResourceEvent(contact, contactResource,
+                            ContactResourceEvent.RESOURCE_MODIFIED));
+                    return true;
+                }
+            }
+        }
+
+        return false;
+    }
+
+    /**
+     * Removes the resource indicated by the fullJid from the list with
+     * resources for the contact.
+     * @param contact from its list of resources to remove
+     * @param fullJid the full jid.
+     * @return whether resource has been updated
+     */
+    private boolean removeResource(ContactJabberImpl contact, String fullJid)
+    {
+        Map<String, ContactResourceJabberImpl> resources =
+            contact.getResourcesMap();
+
+        if (resources.containsKey(fullJid))
+        {
+            ContactResource removedResource = resources.remove(fullJid);
+
+            contact.fireContactResourceEvent(
+                new ContactResourceEvent(contact, removedResource,
+                    ContactResourceEvent.RESOURCE_REMOVED));
+            return true;
+        }
+
+        return false;
+    }
+
     /**
      * Fires the status change, respecting resource priorities.
      * @param presence the presence changed.
@@ -1257,6 +1427,24 @@ public class OperationSetPersistentPresenceJabberImpl
             firePresenceStatusChanged(presence);
         }
 
+        /**
+         * Whether listener is currently storing presence events.
+         * @return
+         */
+        boolean isStoringPresenceEvents()
+        {
+            return storeEvents;
+        }
+
+        /**
+         * Adds presence packet to the list.
+         * @param presence presence packet
+         */
+        void addPresenceEvent(Presence presence)
+        {
+            storedPresences.add(presence);
+        }
+
         /**
          * Sets store events to true.
          */
@@ -1298,19 +1486,23 @@ public class OperationSetPersistentPresenceJabberImpl
                 String userID
                     = StringUtils.parseBareAddress(presence.getFrom());
 
-                List<ChatRoom> chatRooms = parentProvider.getOperationSet(
-                    OperationSetMultiUserChat.class)
-                        .getCurrentlyJoinedChatRooms();
-                for(ChatRoom chatRoom : chatRooms)
+                OperationSetMultiUserChat mucOpSet =
+                    parentProvider.getOperationSet(
+                        OperationSetMultiUserChat.class);
+                if(mucOpSet != null)
                 {
-                    if(chatRoom.getName().equals(userID))
+                    List<ChatRoom> chatRooms
+                        = mucOpSet.getCurrentlyJoinedChatRooms();
+                    for(ChatRoom chatRoom : chatRooms)
                     {
-                        userID = presence.getFrom();
-                        break;
+                        if(chatRoom.getName().equals(userID))
+                        {
+                            userID = presence.getFrom();
+                            break;
+                        }
                     }
                 }
 
-
                 if (logger.isDebugEnabled())
                     logger.debug("Received a status update for buddy=" + userID);
 
@@ -1336,6 +1528,19 @@ public class OperationSetPersistentPresenceJabberImpl
                                         o2, parentProvider).getStatus()
                                       - jabberStatusToPresenceStatus(
                                             o1, parentProvider).getStatus();
+                                // We have run out of "logical" ways to order
+                                // the presences inside the TreeSet. We have
+                                // make sure we are consinstent with equals.
+                                // We do this by comparing the unique resource
+                                // names. If this evaluates to 0 again, then we
+                                // can safely assume this presence object 
+                                // represents the same resource and by that the
+                                // same client.
+                                if(res == 0)
+                                {
+                                    res = o1.getFrom().compareTo(
+                                        o2.getFrom());
+                                }
                             }
 
                             return res;
@@ -1531,6 +1736,12 @@ public class OperationSetPersistentPresenceJabberImpl
 
                 handler.processAuthorizationResponse(response, contact);
             }
+            else if (presenceType == Presence.Type.available
+                    && contactChangesListener != null
+                    && contactChangesListener.isStoringPresenceEvents())
+            {
+                contactChangesListener.addPresenceEvent(presence);
+            }
         }
 
         /**
@@ -1628,9 +1839,9 @@ public class OperationSetPersistentPresenceJabberImpl
 
     /**
      * Runnable that resolves our list against the server side roster.
-     * This thread is the one which will call getRoaster for the first time.
-     * And if roaster is currently processing will wait for it (the wait
-     * is internal into XMPPConnection.getRoaster method).
+     * This thread is the one which will call getRoster for the first time.
+     * And if roster is currently processing will wait for it (the wait
+     * is internal into XMPPConnection.getRoster method).
      */
     private class ServerStoredListInit
         implements Runnable,
@@ -1644,19 +1855,18 @@ public class OperationSetPersistentPresenceJabberImpl
                 .removePacketListener(this);
 
             // init ssList
-            contactChangesListener = new ContactChangesListener();
             ssContactList.init(contactChangesListener);
 
-            // as we have dispatched the contact list and Roaster is ready
+            // as we have dispatched the contact list and Roster is ready
             // lets start the jingle nodes discovery
             parentProvider.startJingleNodesDiscovery();
         }
 
         /**
-         * When roaster packet with no error is received we are ready to
+         * When roster packet with no error is received we are ready to
          * to dispatch the contact list, doing it in different thread
          * to avoid blocking xmpp packet receiving.
-         * @param packet the roaster packet
+         * @param packet the roster packet
          */
         public void processPacket(Packet packet)
         {
