@@ -1,14 +1,26 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.protocol.jabber.extensions.colibri;
 
 import net.java.sip.communicator.impl.protocol.jabber.extensions.*;
 import net.java.sip.communicator.impl.protocol.jabber.extensions.jingle.*;
 
+import net.java.sip.communicator.service.protocol.jabber.*;
 import org.jitsi.service.neomedia.*;
 import org.jitsi.util.*;
 import org.jivesoftware.smack.packet.*;
@@ -25,39 +37,101 @@ import org.xmlpull.v1.*;
 public class ColibriIQProvider
     implements IQProvider
 {
+
+    /**
+     * Smack interoperation layer
+     */
+    private AbstractSmackInteroperabilityLayer smackInteroperabilityLayer =
+            AbstractSmackInteroperabilityLayer.getInstance();
+    
     /** Initializes a new <tt>ColibriIQProvider</tt> instance. */
     public ColibriIQProvider()
     {
-        ProviderManager providerManager = ProviderManager.getInstance();
-
-        providerManager.addExtensionProvider(
+        smackInteroperabilityLayer.addExtensionProvider(
                 PayloadTypePacketExtension.ELEMENT_NAME,
                 ColibriConferenceIQ.NAMESPACE,
                 new DefaultPacketExtensionProvider<PayloadTypePacketExtension>(
                         PayloadTypePacketExtension.class));
-        providerManager.addExtensionProvider(
+        smackInteroperabilityLayer.addExtensionProvider(
+                RtcpFbPacketExtension.ELEMENT_NAME,
+                RtcpFbPacketExtension.NAMESPACE,
+                new DefaultPacketExtensionProvider<RtcpFbPacketExtension>(
+                        RtcpFbPacketExtension.class));
+        smackInteroperabilityLayer.addExtensionProvider(
+                RTPHdrExtPacketExtension.ELEMENT_NAME,
+                ColibriConferenceIQ.NAMESPACE,
+                new DefaultPacketExtensionProvider<RTPHdrExtPacketExtension>(
+                        RTPHdrExtPacketExtension.class));
+        smackInteroperabilityLayer.addExtensionProvider(
                 SourcePacketExtension.ELEMENT_NAME,
                 SourcePacketExtension.NAMESPACE,
                 new DefaultPacketExtensionProvider<SourcePacketExtension>(
                         SourcePacketExtension.class));
-        providerManager.addExtensionProvider(
+        smackInteroperabilityLayer.addExtensionProvider(
                 SourceGroupPacketExtension.ELEMENT_NAME,
                 SourceGroupPacketExtension.NAMESPACE,
                 new DefaultPacketExtensionProvider<SourceGroupPacketExtension>(
                         SourceGroupPacketExtension.class));
 
         PacketExtensionProvider parameterProvider
-            = new DefaultPacketExtensionProvider<ParameterPacketExtension>(
-                    ParameterPacketExtension.class);
+                = new DefaultPacketExtensionProvider<ParameterPacketExtension>(
+                ParameterPacketExtension.class);
 
-        providerManager.addExtensionProvider(
+        smackInteroperabilityLayer.addExtensionProvider(
                 ParameterPacketExtension.ELEMENT_NAME,
                 ColibriConferenceIQ.NAMESPACE,
                 parameterProvider);
-        providerManager.addExtensionProvider(
+        smackInteroperabilityLayer.addExtensionProvider(
                 ParameterPacketExtension.ELEMENT_NAME,
                 SourcePacketExtension.NAMESPACE,
                 parameterProvider);
+        // Shutdown IQ
+        smackInteroperabilityLayer.addIQProvider(
+                ShutdownIQ.GRACEFUL_ELEMENT_NAME,
+                ShutdownIQ.NAMESPACE,
+                this);
+        smackInteroperabilityLayer.addIQProvider(
+                ShutdownIQ.FORCE_ELEMENT_NAME,
+                ShutdownIQ.NAMESPACE,
+                this);
+        // Shutdown extension
+        PacketExtensionProvider shutdownProvider
+                = new DefaultPacketExtensionProvider
+                <ColibriConferenceIQ.GracefulShutdown>(
+                ColibriConferenceIQ.GracefulShutdown.class);
+
+        smackInteroperabilityLayer.addExtensionProvider(
+                ColibriConferenceIQ.GracefulShutdown.ELEMENT_NAME,
+                ColibriConferenceIQ.GracefulShutdown.NAMESPACE,
+                shutdownProvider);
+
+        // ColibriStatsIQ
+        smackInteroperabilityLayer.addIQProvider(
+                ColibriStatsIQ.ELEMENT_NAME,
+                ColibriStatsIQ.NAMESPACE,
+                this);
+
+        // ColibriStatsExtension
+        PacketExtensionProvider statsProvider
+                = new DefaultPacketExtensionProvider<ColibriStatsExtension>(
+                ColibriStatsExtension.class);
+
+        smackInteroperabilityLayer.addExtensionProvider(
+                ColibriStatsExtension.ELEMENT_NAME,
+                ColibriStatsExtension.NAMESPACE,
+                statsProvider);
+        // ColibriStatsExtension.Stat
+        PacketExtensionProvider statProvider
+                = new DefaultPacketExtensionProvider
+                <ColibriStatsExtension.Stat>(
+                ColibriStatsExtension.Stat.class);
+
+        smackInteroperabilityLayer.addExtensionProvider(
+                ColibriStatsExtension.Stat.ELEMENT_NAME,
+                ColibriStatsExtension.NAMESPACE,
+                statProvider);    
+        
+        
     }
 
     private void addChildExtension(
@@ -96,6 +170,13 @@ public class ColibriIQProvider
 
             channel.addSourceGroup(sourceGroup);
         }
+        else if (childExtension instanceof RTPHdrExtPacketExtension)
+        {
+            RTPHdrExtPacketExtension rtpHdrExtPacketExtension
+                    = (RTPHdrExtPacketExtension) childExtension;
+
+            channel.addRtpHeaderExtension(rtpHdrExtPacketExtension);
+        }
     }
 
     private void addChildExtension(
@@ -131,8 +212,7 @@ public class ColibriIQProvider
         throws Exception
     {
         PacketExtensionProvider extensionProvider
-            = (PacketExtensionProvider)
-                ProviderManager.getInstance().getExtensionProvider(
+            = smackInteroperabilityLayer.getExtensionProvider(
                         name,
                         namespace);
         PacketExtension extension;
@@ -181,6 +261,12 @@ public class ColibriIQProvider
             if ((conferenceID != null) && (conferenceID.length() != 0))
                 conference.setID(conferenceID);
 
+            String conferenceName = parser
+                .getAttributeValue("", ColibriConferenceIQ.NAME_ATTR_NAME);
+
+            if ((conferenceName != null) && (conferenceName.length() != 0))
+                conference.setName(conferenceName);
+
             boolean done = false;
             ColibriConferenceIQ.Channel channel = null;
             ColibriConferenceIQ.RTCPTerminationStrategy rtcpTerminationStrategy
@@ -191,6 +277,7 @@ public class ColibriIQProvider
             ColibriConferenceIQ.Recording recording = null;
             ColibriConferenceIQ.Endpoint conferenceEndpoint = null;
             StringBuilder ssrc = null;
+            SourcePacketExtension ssrcPe = null;
 
             while (!done)
             {
@@ -256,6 +343,15 @@ public class ColibriIQProvider
                         }
                         ssrc = null;
                     }
+                    else if (SourcePacketExtension.ELEMENT_NAME.equals(name))
+                    {
+                        if (channel != null && ssrcPe != null)
+                        {
+                            channel.addSource(ssrcPe);
+                        }
+
+                        ssrcPe = null;
+                    }
                     else if (ColibriConferenceIQ.Content.ELEMENT_NAME.equals(
                             name))
                     {
@@ -275,6 +371,11 @@ public class ColibriIQProvider
                         conference.setRecording(recording);
                         recording = null;
                     }
+                    else if (ColibriConferenceIQ.GracefulShutdown.ELEMENT_NAME
+                        .equals(name))
+                    {
+                        conference.setGracefulShutdown(true);
+                    }
                     break;
                 }
 
@@ -327,6 +428,15 @@ public class ColibriIQProvider
                         if ((expire != null) && (expire.length() != 0))
                             channel.setExpire(Integer.parseInt(expire));
 
+                        String packetDelay
+                            = parser.getAttributeValue(
+                                    "",
+                                    ColibriConferenceIQ.Channel
+                                            .PACKET_DELAY_ATTR_NAME);
+                        if (!StringUtils.isNullOrEmpty(packetDelay))
+                            channel.setPacketDelay(
+                                    Integer.parseInt(packetDelay));
+
                         // host
                         String host
                             = parser.getAttributeValue(
@@ -375,6 +485,29 @@ public class ColibriIQProvider
                             channel.setAdaptiveLastN(
                                     Boolean.parseBoolean(adaptiveLastN));
 
+                        String adaptiveSimulcast
+                            = parser.getAttributeValue(
+                                    "",
+                                    ColibriConferenceIQ.Channel
+                                            .ADAPTIVE_SIMULCAST_ATTR_NAME);
+
+                        if (!StringUtils.isNullOrEmpty(adaptiveSimulcast))
+                        {
+                            channel.setAdaptiveSimulcast(
+                                    Boolean.parseBoolean(adaptiveSimulcast));
+                        }
+
+                        // simulcastMode
+                        String simulcastMode
+                                = parser.getAttributeValue(
+                                "",
+                                ColibriConferenceIQ.Channel
+                                        .SIMULCAST_MODE_ATTR_NAME);
+
+                        if (!StringUtils.isNullOrEmpty(simulcastMode))
+                            channel.setSimulcastMode(
+                                    SimulcastMode.fromString(simulcastMode));
+
                         // receiving simulcast layer
                         String receivingSimulcastLayer
                                 = parser.getAttributeValue(
@@ -458,6 +591,20 @@ public class ColibriIQProvider
                     {
                         ssrc = new StringBuilder();
                     }
+                    else if (SourcePacketExtension.ELEMENT_NAME.equals(name))
+                    {
+                        ssrcPe = new SourcePacketExtension();
+
+                        String ssrcStr
+                            = parser.getAttributeValue(
+                                    "",
+                                    SourcePacketExtension.SSRC_ATTR_NAME);
+
+                        if (!StringUtils.isNullOrEmpty(ssrcStr))
+                        {
+                            ssrcPe.setSSRC(Long.parseLong(ssrcStr));
+                        }
+                    }
                     else if (ColibriConferenceIQ.Content.ELEMENT_NAME.equals(
                             name))
                     {
@@ -479,8 +626,6 @@ public class ColibriIQProvider
                                 = parser.getAttributeValue(
                                 "",
                                 ColibriConferenceIQ.Recording.STATE_ATTR_NAME);
-                        boolean state = Boolean.parseBoolean(stateStr);
-
                         String token
                                 = parser.getAttributeValue(
                                 "",
@@ -488,7 +633,7 @@ public class ColibriIQProvider
 
                         recording
                                 = new ColibriConferenceIQ.Recording(
-                                state,
+                                stateStr,
                                 token);
                     }
                     else if (ColibriConferenceIQ.SctpConnection.ELEMENT_NAME
@@ -607,6 +752,30 @@ public class ColibriIQProvider
                             peName = name;
                             peNamespace = namespace;
                         }
+                        else if (RtcpFbPacketExtension.ELEMENT_NAME.equals(
+                                name)
+                                && RtcpFbPacketExtension.NAMESPACE
+                                .equals(parser.getNamespace()))
+                        {
+                            /*
+                             * The channel element of the Jitsi Videobridge
+                             * protocol reuses the payload-type element defined
+                             * in XEP-0167: Jingle RTP Sessions.
+                             */
+                            peName = name;
+                            peNamespace = namespace;
+                        }
+                        else if (RTPHdrExtPacketExtension.ELEMENT_NAME.equals(
+                                name))
+                        {
+                            /*
+                             * The channel element of the Jitsi Videobridge
+                             * protocol reuses the rtp-hdrext element defined
+                             * in XEP-0167: Jingle RTP Sessions.
+                             */
+                            peName = name;
+                            peNamespace = namespace;
+                        }
                         else if (RawUdpTransportPacketExtension.ELEMENT_NAME
                                     .equals(name)
                                 && RawUdpTransportPacketExtension.NAMESPACE
@@ -666,6 +835,92 @@ public class ColibriIQProvider
 
             iq = conference;
         }
+        else if (ShutdownIQ.NAMESPACE.equals(namespace) &&
+                 ShutdownIQ.isValidElementName(parser.getName()))
+        {
+            String rootElement = parser.getName();
+
+            iq = ShutdownIQ.createShutdownIQ(rootElement);
+
+            boolean done = false;
+
+            while (!done)
+            {
+                switch (parser.next())
+                {
+                    case XmlPullParser.END_TAG:
+                    {
+                        String name = parser.getName();
+
+                        if (rootElement.equals(name))
+                        {
+                            done = true;
+                        }
+                        break;
+                    }
+                }
+            }
+        }
+        else if (ColibriStatsIQ.ELEMENT_NAME.equals(parser.getName())
+            && ColibriStatsIQ.NAMESPACE.equals(namespace))
+        {
+            String rootElement = parser.getName();
+
+            ColibriStatsIQ statsIQ = new ColibriStatsIQ();
+            iq = statsIQ;
+            ColibriStatsExtension.Stat stat = null;
+
+            boolean done = false;
+
+            while (!done)
+            {
+                switch (parser.next())
+                {
+                    case XmlPullParser.START_TAG:
+                    {
+                        String name = parser.getName();
+
+                        if (ColibriStatsExtension.Stat
+                                    .ELEMENT_NAME.equals(name))
+                        {
+                            stat = new ColibriStatsExtension.Stat();
+
+                            String statName
+                                = parser.getAttributeValue(
+                                    "",
+                                    ColibriStatsExtension.Stat.NAME_ATTR_NAME);
+                            stat.setName(statName);
+
+                            String statValue
+                                = parser.getAttributeValue(
+                                    "",
+                                    ColibriStatsExtension.Stat.VALUE_ATTR_NAME);
+                            stat.setValue(statValue);
+                        }
+                        break;
+                    }
+                    case XmlPullParser.END_TAG:
+                    {
+                        String name = parser.getName();
+
+                        if (rootElement.equals(name))
+                        {
+                            done = true;
+                        }
+                        else if (ColibriStatsExtension.Stat.ELEMENT_NAME
+                            .equals(name))
+                        {
+                            if (stat != null)
+                            {
+                                statsIQ.addStat(stat);
+                                stat = null;
+                            }
+                        }
+                        break;
+                    }
+                }
+            }
+        }
         else
             iq = null;
 
