@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.impl.protocol.sip;
 
@@ -558,7 +569,7 @@ public class SipStackSharing
             if(recipient == null)
             {
                 logger.error("Dialog wasn't marked, please report this to "
-                                + "dev@sip-communicator.dev.java.net");
+                                + "dev@jitsi.org");
             }
             else
             {
@@ -650,7 +661,7 @@ public class SipStackSharing
                 {
                     logger.error(
                         "couldn't create transaction, please report "
-                            + "this to dev@sip-communicator.dev.java.net",
+                            + "this to dev@jitsi.org",
                         ex);
                 }
             }
@@ -754,7 +765,7 @@ public class SipStackSharing
             {
                 logger.error("We received a response which "
                                 + "wasn't marked, please report this to "
-                                + "dev@sip-communicator.dev.java.net");
+                                + "dev@jitsi.org");
             }
         }
         catch(Throwable exc)
@@ -792,7 +803,7 @@ public class SipStackSharing
             {
                 logger.error("We received a timeout which wasn't "
                                 + "marked, please report this to "
-                                + "dev@sip-communicator.dev.java.net");
+                                + "dev@jitsi.org");
             }
             else
             {
@@ -832,7 +843,7 @@ public class SipStackSharing
             {
                 logger.error("We received a transaction terminated which wasn't"
                                 + " marked, please report this to"
-                                + " dev@sip-communicator.dev.java.net");
+                                + " dev@jitsi.org");
             }
             else
             {
@@ -1016,11 +1027,21 @@ public class SipStackSharing
                     List<ProtocolProviderServiceSipImpl> candidates,
                     Request                              request)
     {
-        Iterator<ProtocolProviderServiceSipImpl> iterPP = candidates.iterator();
+        Iterator<ProtocolProviderServiceSipImpl> iterPP =
+            candidates.iterator();
         while (iterPP.hasNext())
         {
             ProtocolProviderServiceSipImpl candidate = iterPP.next();
-
+            boolean forceProxyBypass
+                = candidate.getAccountID()
+                    .getAccountPropertyBoolean(
+                        ProtocolProviderFactory.FORCE_PROXY_BYPASS, false);
+            if(forceProxyBypass)
+            {
+                // Proxy check is disabled all connections are
+                // ok (HA sipXecs, sipXcom, ...)
+                continue;
+            } 
             if(candidate.getRegistrarConnection() == null)
             {
                 //RegistrarLess connections are ok
