@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.plugin.generalconfig;
 
@@ -225,6 +236,30 @@ public class GeneralConfigurationPanel
         return autoStartCheckBox;
     }
 
+    /**
+     * Initializes the minimize instead of hide checkbox.
+     */
+    public Component createMinimzeInsteadOfHideCheckBox()
+    {
+        JCheckBox chk = new SIPCommCheckBox();
+
+        chk.setText(
+            Resources.getString("plugin.generalconfig.MINIMIZE_NOT_HIDE"));
+        chk.addActionListener(new ActionListener()
+        {
+            public void actionPerformed(ActionEvent e)
+            {
+                boolean value = ((JCheckBox) e.getSource()).isSelected();
+                ConfigurationUtils.setIsMinimizeInsteadOfHide(value);
+                UtilActivator.getUIService().setExitOnMainWindowClose(
+                    !UtilActivator.getSystrayService().checkInitialized());
+            }
+        });
+
+        chk.setSelected(ConfigurationUtils.isMinimizeInsteadOfHide());
+        return chk;
+    }
+
     /**
      * Creates the message configuration panel.
      * @return the created panel
@@ -716,8 +751,8 @@ public class GeneralConfigurationPanel
             LocaleItem lm = (LocaleItem)value;
             if (value != null)
             {
-                labels[0].setText(lm.locale.getDisplayLanguage());
-                labels[1].setText(lm.locale.getDisplayLanguage(lm.locale));
+                labels[0].setText(lm.locale.getDisplayName());
+                labels[1].setText(lm.locale.getDisplayName(lm.locale));
                 labels[2].setText(Resources.getString(
                     "plugin.generalconfig.DEFAULT_LANGUAGE_TRANSLATED",
                     new String[]{
@@ -948,15 +983,17 @@ public class GeneralConfigurationPanel
      */
     public Component createStartupConfigPanel()
     {
-        if (!OSUtils.IS_WINDOWS)
-            return null;
-
         JPanel updateConfigPanel = GeneralConfigPluginActivator.
             createConfigSectionComponent(
                 Resources.getString("plugin.generalconfig.STARTUP_CONFIG"));
 
-        updateConfigPanel.add(createAutoStartCheckBox());
-        updateConfigPanel.add(createUpdateCheckBox());
+        updateConfigPanel.add(createMinimzeInsteadOfHideCheckBox());
+        if (OSUtils.IS_WINDOWS)
+        {
+            updateConfigPanel.add(createAutoStartCheckBox());
+            updateConfigPanel.add(createUpdateCheckBox());
+        }
+
         return updateConfigPanel;
     }
 
