@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.service.protocol;
 
@@ -12,7 +23,6 @@ import java.util.*;
 import net.java.sip.communicator.service.protocol.event.*;
 import net.java.sip.communicator.util.*;
 
-import org.jitsi.service.protocol.event.*;
 import org.jitsi.util.event.*;
 
 /**
@@ -391,6 +401,11 @@ public abstract class AbstractCallPeer<T extends Call,
         {
             CallPeerListener listener = listeners.next();
 
+            if (logger.isDebugEnabled())
+                logger.debug("Dispatching a CallPeerChangeEvent event to "
+                    + listener.getClass()
+                    +" . event is: " + evt.toString());
+
             // catch any possible errors, so we are sure we dispatch events
             // to all listeners
             try
