@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.service.protocol.jabber;
 
@@ -350,28 +361,6 @@ public class JabberAccountID
         putAccountProperty(ProtocolProviderFactory.IS_USE_ICE, isUseIce);
     }
 
-    /**
-     * Indicates if ice should be used for this account.
-     * @return <tt>true</tt> if ICE should be used for this account, otherwise
-     * returns <tt>false</tt>
-     */
-    public boolean isUseGoogleIce()
-    {
-        return getAccountPropertyBoolean(
-                ProtocolProviderFactory.IS_USE_GOOGLE_ICE, true);
-    }
-
-    /**
-     * Sets the <tt>useGoogleIce</tt> property.
-     * @param isUseIce <tt>true</tt> to indicate that ICE should be used for
-     * this account, <tt>false</tt> - otherwise.
-     */
-    public void setUseGoogleIce(boolean isUseIce)
-    {
-        putAccountProperty(
-                ProtocolProviderFactory.IS_USE_GOOGLE_ICE, isUseIce);
-    }
-
     /**
      * Indicates if the stun server should be automatically discovered.
      * @return <tt>true</tt> if the stun server should be automatically
