@@ -1,8 +1,19 @@
 /*
  * Jitsi, the OpenSource Java VoIP and Instant Messaging client.
  *
- * Distributable under LGPL license.
- * See terms of license at gnu.org.
+ * Copyright @ 2015 Atlassian Pty Ltd
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package net.java.sip.communicator.service.protocol.media;
 
@@ -27,7 +38,7 @@ import org.jitsi.util.event.*;
  * A utility class implementing media control code shared between current
  * telephony implementations. This class is only meant for use by protocol
  * implementations and should not be accessed by bundles that are simply using
- * the telephony functionalities.
+ * the telephony functionality.
  *
  * @param <T> the peer extension class like for example <tt>CallPeerSipImpl</tt>
  * or <tt>CallPeerJabberImpl</tt>
@@ -363,7 +374,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
             if (call == null)
                 return;
 
-            for (MediaType mediaType : MediaType.values())
+            for (MediaType mediaType : new MediaType[] {MediaType.AUDIO, MediaType.VIDEO} )
             {
                 MediaStream stream = getStream(mediaType);
 
@@ -611,6 +622,8 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
             return audioDirectionUserPreference;
         case VIDEO:
             return videoDirectionUserPreference;
+        case DATA:
+            return MediaDirection.INACTIVE;
         default:
             throw new IllegalArgumentException("mediaType");
         }
@@ -655,7 +668,10 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
      */
     protected List<RTPExtension> getExtensionsForType(MediaType type)
     {
-        return getDefaultDevice(type).getSupportedExtensions();
+        MediaDevice device = getDefaultDevice(type);
+        return device != null
+            ? device.getSupportedExtensions()
+            : new ArrayList<RTPExtension>();
     }
 
     /**
@@ -673,7 +689,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
 
         return
             (transportManager == null)
-                ? null
+                ? 0
                 : transportManager.getHarvestingTime(harvesterName);
     }
 
@@ -926,7 +942,9 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
     /**
      * Returns the number of harvesting for this agent.
      *
-     * @return The number of harvesting for this agent.
+     * @return The number of harvesting for this agent. 0 if this harvester
+     * does not exists, if the ICE agent is null, or
+     * if the agent has never harvested with this harvester.
      */
     public int getNbHarvesting()
     {
@@ -934,7 +952,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
 
         return
             (transportManager == null)
-                ? null
+                ? 0
                 : transportManager.getNbHarvesting();
     }
 
@@ -945,7 +963,8 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
      * @param harvesterName The class name if the harvester.
      *
      * @return The number of harvesting time for the harvester given in
-     * parameter.
+     * parameter. 0 if this harvester does not exists, if the ICE agent is null, or if the
+     * agent has never harvested with this harvester.
      */
     public int getNbHarvesting(String harvesterName)
     {
@@ -953,7 +972,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
 
         return
             (transportManager == null)
-                ? null
+                ? 0
                 : transportManager.getNbHarvesting(harvesterName);
     }
 
@@ -1030,7 +1049,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
         case VIDEO:
             return videoStream;
         default:
-            throw new IllegalArgumentException("mediaType");
+            return null;
         }
     }
 
@@ -1038,7 +1057,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
      * Returns the total harvesting time (in ms) for all harvesters.
      *
      * @return The total harvesting time (in ms) for all the harvesters. 0 if
-     * the ICE agent is null, or if the agent has nevers harvested.
+     * the ICE agent is null, or if the agent has never harvested.
      */
     public long getTotalHarvestingTime()
     {
@@ -1046,7 +1065,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
 
         return
             (transportManager == null)
-                ? null
+                ? 0
                 : transportManager.getTotalHarvestingTime();
     }
 
@@ -1801,6 +1820,11 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
                 if (srtpListener != null)
                     this.mediaHandler.removeSrtpListener(srtpListener);
                 this.mediaHandler.removeVideoListener(videoStreamVideoListener);
+
+                // We intentionally do not remove our Call from the list of
+                // DTMF listeners. It should stay there as long as the
+                // MediaHandler is used by at least one CallPeer/CPMH.
+                //this.mediaHandler.removeDtmfListener(getPeer().getCall());
             }
 
             this.mediaHandler = mediaHandler;
@@ -1838,6 +1862,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
                 if (srtpListener != null)
                     this.mediaHandler.addSrtpListener(srtpListener);
                 this.mediaHandler.addVideoListener(videoStreamVideoListener);
+                this.mediaHandler.addDtmfListener(getPeer().getCall());
             }
         }
     }
@@ -2022,7 +2047,7 @@ public abstract class CallPeerMediaHandler<T extends MediaAwareCallPeer<?,?,?>>
      */
      public String getLabel(MediaType mediaType)
     {
-        return mediaType.toString();
+        return mediaType.toString() + hashCode();
     }
 
     /**
